@@ -1,3 +1,3 @@
 use super::*;
 
-mod kubeadm;
+pub mod kubeadm;
