@@ -12,9 +12,14 @@ impl AWSMachineTemplate {
         Self::with_type(name, "t3.small")
     }
 
+    pub fn m5large(name: &str) -> Self {
+        Self::with_type(name, "m5.large")
+    }
+
     pub fn m5xlarge(name: &str) -> Self {
         Self::with_type(name, "m5.xlarge")
     }
+
     pub fn m5dxlarge(name: &str) -> Self {
         Self::with_type(name, "m5d.xlarge")
     }
@@ -35,6 +40,14 @@ impl AWSMachineTemplate {
         Self::with_type(name, "m6gd.4xlarge")
     }
 
+    pub fn m6ilarge(name: &str) -> Self {
+        Self::with_type(name, "m6i.large")
+    }
+
+    pub fn m6ixlarge(name: &str) -> Self {
+        Self::with_type(name, "m6i.xlarge")
+    }
+
     #[must_use]
     pub fn ssh_key_name(mut self, name: &str) -> Self {
         self.spec.template.spec.ssh_key_name = Some(name.to_string());
@@ -75,8 +88,8 @@ impl AWSMachineTemplate {
     }
 
     #[must_use]
-    pub fn non_root_volumes(mut self, volumes: Vec<Volume>) -> Self {
-        self.spec.template.spec.non_root_volumes = volumes;
+    pub fn non_root_volumes(mut self, volumes: impl IntoIterator<Item = Volume>) -> Self {
+        self.spec.template.spec.non_root_volumes = volumes.into_iter().collect();
         self
     }
 
